@@ -1,22 +1,30 @@
 from zipfile import ZipFile
 from nonebot.log import logger
-import requests
+import httpx
+import re
 import os
 try:
     import py7zr
 except:
     pass
 from pathlib import Path
-from .image import txt_to_img
-from .config import map_path
-from .anne import *
+from .txt_to_img import txt_to_img
+from .config import *
+# from .l4d2_anne.__init__ import *
+from .l4d2_anne import write_player,del_player,anne_messgae
+from .chrome import get_anne_server
+from .l4d2_server.rcon import read_server_cfg_rcon,rcon_server
+from .l4d2_image.draw_user_info import draw_user_info_img
+from .l4d2_queries import queries
+
+
 
 def get_file(url,down_file):
     '''
     下载指定Url到指定位置
     '''
     try:
-        maps = requests.get(url)
+        maps = httpx.get(url)
         logger.info('已获取文件，尝试新建文件并写入')
         with open(down_file ,'wb') as mfile:
             mfile.write(maps.content)
@@ -46,7 +54,7 @@ def mes_list(mes,name_list:list):
 
 def support_gbk(zip_file: ZipFile):
     '''
-    中文恢复
+    压缩包中文恢复
     '''
     name_to_info = zip_file.NameToInfo
     # copy map first
@@ -112,14 +120,12 @@ def solve(s):
         return ''
     return s.rsplit('\n', 1)[0]
 
-def search_anne(name:str,usr_id:str):
-    """获取anne信息"""
-    name = id_to_mes(name,usr_id)
-    if len(name)== 0:
-        return '绑定信息不存在，或已失效'
-    msg = anne_search(name)
-    msg = solve(msg)
+async def search_anne(name:str,usr_id:str):
+    msg = await anne_messgae(name,usr_id)
+    if type(msg) == str:
+        msg = solve(msg)
     return msg
+    
 
 def bind_steam(id:str,msg:str,nickname:str):
     """绑定qq-steam"""
@@ -127,4 +133,59 @@ def bind_steam(id:str,msg:str,nickname:str):
 
 def name_exist(id:str):
     """删除绑定信息"""
-    return del_player(id)
\ No newline at end of file
+    return del_player(id)
+
+async def get_message_at(data: str) -> list:
+    '''
+    获取at列表
+    :param data: event.json()
+    抄的groupmate_waifu
+    '''
+    qq_list = []
+    data = json.loads(data)
+    try:
+        for msg in data['message']:
+            if msg['type'] == 'at':
+                qq_list.append(int(msg['data']['qq']))
+        return qq_list
+    except Exception:
+        return []
+    
+def anne_servers():
+    mes = get_anne_server()
+    mes = solve(mes)
+    return mes
+
+def at_to_usrid(usr_id,at):
+    """at对象变qqid否则返回usr_id"""
+    if at != []:
+        if at and at[0] != usr_id:
+            at = at[0]
+        usr_id = at
+    return usr_id
+
+async def command_server(msg:str):
+    """rcon控制台返回信息"""
+    logger.info(cfg_server)
+    rcon = await read_server_cfg_rcon()
+    logger.info([msg,l4_host,l4_port,rcon])
+    msg = await rcon_server(rcon,msg)
+    logger.info(msg)
+    if len(msg)==0:
+        msg = '你可能发送了一个无用指令，或者换图导致服务器无响应'
+    if msg.startswith('Unknown command'):
+        msg = msg.replace('Unknown command','').strip()
+        msg = '无效指令：' + msg
+    msg = msg.strip()
+    return msg
+
+def split_maohao(msg:str) -> list:
+    """分割大小写冒号"""
+    msg:list = re.split(":|：",msg.strip())
+    msg[-1] = msg[-1] if len(msg[-1])!=0 else '20715'  
+    return msg
+
+def queries_server(msg:list) -> str:
+    """查询ip返回信息"""
+    print(msg)
+    return queries(msg[0],msg[1])
\ No newline at end of file
